#[non_exhaustive]pub enum Error {
InvalidFormat(&'static str),
Io(Error),
NotFound(&'static str),
BlankValue(&'static str),
TooBig(&'static str),
NotSupported(&'static str),
UnexpectedValue(&'static str),
PartialResult(PartialResult),
}Expand description
An error returned when parsing of Exif data fails.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
InvalidFormat(&'static str)
Input data was malformed or truncated.
Io(Error)
Input data could not be read due to an I/O error and
a std::io::Error value is associated with this variant.
NotFound(&'static str)
Exif attribute information was not found in an image file such as JPEG.
BlankValue(&'static str)
The value of the field is blank. Some fields have blank values whose meanings are defined as “unknown”. Such a blank value should be treated the same as the absence of the field.
TooBig(&'static str)
Field values or image data are too big to encode.
NotSupported(&'static str)
The field type is not supported and cannnot be encoded.
UnexpectedValue(&'static str)
The field has an unexpected value.
PartialResult(PartialResult)
Partially-parsed result and errors. This can be returned only when
Reader::continue_on_error is enabled.
Implementations
Sourceimpl Error
impl Error
Sourcepub fn distill_partial_result<F>(self, f: F) -> Result<Exif, Self>
pub fn distill_partial_result<F>(self, f: F) -> Result<Exif, Self>
Extracts Exif and Vec<Error> from Error::PartialResult.
If self is Error::PartialResult,
ignored errors are passed to f as Vec<Error> and
partially-parsed result is retuend in Ok.
Otherwise, Err(self) is returned.